@@ -1,4 +1,5 @@
 
+# $Id: Ace.pm,v 1.9 2001/06/18 15:53:42 dag Exp $
 #
 # BioPerl module for Bio::DB::Ace
 #
@@ -57,9 +58,8 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-  vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org              - General discussion
+  http://bioperl.org/MailList.shtml  - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -83,12 +83,12 @@ The rest of the documentation details each of the object methods. Internal metho
 # Let the code begin...
 
 package Bio::DB::Ace;
-use vars qw($AUTOLOAD @ISA @EXPORT_OK);
+use vars qw(@ISA);
 use strict;
 
-# Object preamble - inherits from Bio::DB::Abstract
+# Object preamble - inherits from Bio::DB::RandomAccessI
 
-use Bio::DB::BioSeqI;
+use Bio::DB::RandomAccessI;
 use Bio::Seq;
 
 BEGIN { 
@@ -101,16 +101,15 @@ BEGIN {
 }
 
 
-@ISA = qw(Bio::DB::BioSeqI Bio::Root::Object Exporter);
-@EXPORT_OK = qw();
+@ISA = qw(Bio::DB::RandomAccessI);
 
 # new() is inherited from Bio::DB::Abstract
 
 # _initialize is where the heavy stuff will happen when new is called
 
-sub _initialize {
-  my($self,@args) = @_;
-  my $make = $self->SUPER::_initialize;
+sub new {
+  my($class,@args) = @_;
+  my $self = $class->SUPER::new(@args);
   my ($host,$port) = $self->_rearrange([qw(
 					 HOST
 					 PORT
@@ -129,7 +128,7 @@ sub _initialize {
   $self->_aceobj($aceobj);
 
 
-  return $make; # success - we hope!
+  return $self;
 }
 
 =head2 get_Seq_by_id
@@ -190,7 +189,7 @@ sub get_Seq_by_acc {
   Args    : New value of the ace object
 
 =cut
-  
+
 sub _aceobj {
   my ($self,$arg) = @_;
 
@@ -202,3 +201,9 @@ sub _aceobj {
 }
 
 1;
+
+
+
+
+
+
