@@ -1,4 +1,4 @@
-# $Id: PrimarySeq.pm,v 1.24.2.5 2001/10/26 19:06:03 jason Exp $
+# $Id: PrimarySeq.pm,v 1.42.2.2 2002/03/15 12:36:15 heikki Exp $
 #
 # bioperl module for Bio::PrimarySeq
 #
@@ -24,14 +24,18 @@ Bio::PrimarySeq - Bioperl lightweight Sequence Object
 
   #make from memory
   $seqobj = Bio::PrimarySeq->new ( -seq => 'ATGGGGTGGGCGGTGGGTGGTTTG',
-			    -id  => 'GeneFragment-12',
-			    -accession_number => 'X78121',
-			    -moltype => 'dna'
-			    );
+				   -id  => 'GeneFragment-12',
+				   -accession_number => 'X78121',
+				   -alphabet => 'dna',
+				   -is_circular => 1
+				   );
+  print "Sequence ", $seqobj->id(), " with accession ", 
+    $seqobj->accession_number, "\n";
 
   # read from file
   $inputstream = Bio::SeqIO->new(-file => "myseq.fa",-format => 'Fasta');
   $seqobj = $inputstream->next_seq();
+  print "Sequence ", $seqobj->id(), " and desc ", $seqobj->desc, "\n";
 
   # get from database
   $db = Bio::DB::GenBank->new();
@@ -39,13 +43,13 @@ Bio::PrimarySeq - Bioperl lightweight Sequence Object
 
   # to get out parts of the sequence.
 
-  print "Sequence ", $seqobj->id(), " with accession ", $seqobj->accession, " and desc ", $seqobj->desc, "\n";
+  print "Sequence ", $seqobj->id(), " with accession ", 
+    $seqobj->accession_number, " and desc ", $seqobj->desc, "\n";
 
   $string  = $seqobj->seq();
   $string2 = $seqobj->subseq(1,40);
 
 
-
 =head1 DESCRIPTION
 
 PrimarySeq is a lightweight Sequence object, storing little more than
@@ -97,23 +101,6 @@ For writing files, a similar system is used
      $outputstream = Bio::SeqIO->new( -fh => \*OUTPUT, -format => 'Fasta');
      $outputstream->write_seq($seqobj);
 
-=head2 Deprecated methods
-
-A number of methods which were present in the old 0.04/0.05 series
-have been deprecated.  Most of these methods work as before, but
-provide a warning that someone has called a deprecated method.
-
-=over 4
-
-=item getseq - use seq/subseq instead
-
-=item str - use seq/subseq instead
-
-=item ary - use seq/subseq with your own split afterwards
-
-=item type - use moltype, but notice that moltype returns different values (lowercase)
-
-=back
 
 =head1 FEEDBACK
 
@@ -143,7 +130,8 @@ Describe contact details here
 
 =head1 APPENDIX
 
-The rest of the documentation details each of the object methods. Internal methods are usually preceded with a _
+The rest of the documentation details each of the object
+methods. Internal methods are usually preceded with a _
 
 =cut
 
@@ -155,13 +143,13 @@ package Bio::PrimarySeq;
 use vars qw(@ISA %valid_type);
 use strict;
 
-use Bio::Root::RootI;
+use Bio::Root::Root;
 use Bio::PrimarySeqI;
 
-@ISA = qw(Bio::Root::RootI Bio::PrimarySeqI);
+@ISA = qw(Bio::Root::Root Bio::PrimarySeqI);
 
 #
-# setup the allowed values for moltype()
+# setup the allowed values for alphabet()
 #
 BEGIN {
     %valid_type = map {$_, 1} qw( dna rna protein );
@@ -181,7 +169,7 @@ BEGIN {
 
            Note that you can provide an empty sequence string. However, in
            this case you MUST specify the type of sequence you wish to
-           initialize by the parameter -moltype. See moltype() for possible
+           initialize by the parameter -alphabet. See alphabet() for possible
            values.
  Returns : a new Bio::PrimarySeq object
  Args    : -seq         => sequence string
@@ -189,7 +177,7 @@ BEGIN {
            -accession_number => accession number
            -primary_id  => primary id (Genbank id)
            -desc        => description text
-           -moltype     => molecule type (dna,rna,prot)
+           -alphabet     => molecule type (dna,rna,protein)
            -id          => alias for display id
 
 =cut
@@ -199,34 +187,37 @@ sub new {
     my ($class, @args) = @_;
     my $self = $class->SUPER::new(@args);
 
-    my($seq,$id,$acc,$pid,$desc,$moltype,$given_id) =
+    my($seq,$id,$acc,$pid,$desc,$alphabet,$given_id,$is_circular) =
 	$self->_rearrange([qw(SEQ
 			      DISPLAY_ID
 			      ACCESSION_NUMBER
 			      PRIMARY_ID
 			      DESC
-			      MOLTYPE
+			      ALPHABET
 			      ID
+			      IS_CIRCULAR
 			      )],
 			  @args);
 
 
     if( defined $id && defined $given_id ) {
 	if( $id ne $given_id ) {
-	    $self->throw("Provided both id and display_id constructor functions. [$id] [$given_id]");	
+	    $self->throw("Provided both id and display_id constructor ".
+			 "functions. [$id] [$given_id]");	
 	}
     }
     if( defined $given_id ) { $id = $given_id; }
 
-    # if moltype is provided we set it first, so that it won't be guessed
+    # if alphabet is provided we set it first, so that it won't be guessed
     # when the sequence is set
-    $moltype && $self->moltype($moltype);
+    $alphabet && $self->alphabet($alphabet);
     # note: the sequence string may be empty
     $self->seq($seq) if defined($seq);
     $id      && $self->display_id($id);
     $acc     && $self->accession_number($acc);
     $pid     && $self->primary_id($pid);
     $desc    && $self->desc($desc);
+    $is_circular && $self->is_circular($is_circular);
 
     return $self;
 }
@@ -248,15 +239,16 @@ sub seq {
 
    if( defined $value) {
        if(! $obj->validate_seq($value)) {
-	   $obj->throw("Attempting to set the sequence to [$value] which does not look healthy");
+	   $obj->throw("Attempting to set the sequence to [$value] ".
+		       "which does not look healthy");
        }
        # if a sequence was already set we make sure that we re-adjust the
        # mol.type, otherwise we skip guessing if mol.type is already set
        my $is_changed_seq = exists($obj->{'seq'});
        $obj->{'seq'} = $value;
        if(($is_changed_seq && (CORE::length($value) > 0)) ||
-	  (! defined($obj->moltype()))) {
-	   $obj->_guess_type();
+	  (! defined($obj->alphabet()))) {
+	   $obj->_guess_alphabet();
        }
     }
    return $obj->{'seq'};
@@ -273,12 +265,12 @@ sub seq {
            must be accepted by seq(). A string that does not validate will
            lead to an exception if passed to seq().
 
-           The implementation provided here does not take moltype() into
-           account. Allowed are all letters (A-Z) and '-','.', and '*'.
+           The implementation provided here does not take alphabet() into
+           account. Allowed are all letters (A-Z) and '-','.', '*' and '?'.
 
  Example :
- Returns : TRUE if the supplied sequence string is valid for the object, and
-           FALSE otherwise.
+ Returns : 1 if the supplied sequence string is valid for the object, and
+           0 otherwise.
  Args    : The sequence string to be validated.
 
 
@@ -287,7 +279,7 @@ sub seq {
 sub validate_seq {
    my ($self,$seqstr) = @_;
 
-   if((CORE::length($seqstr) > 0) && ($seqstr !~ /^[A-Za-z\-\.\*]+$/)) {
+   if((CORE::length($seqstr) > 0) && ($seqstr !~ /^[A-Za-z\-\.\*\?]+$/)) {
        return 0;
    }
    return 1;
@@ -301,28 +293,63 @@ sub validate_seq {
            is 1 and the number is inclusive, ie 1-2 are the first two
            bases of the sequence
  Returns : a string
- Args    :
-
+ Args    : integer for start position
+           integer for end position
 
+           OR
+           Bio::LocationI location for subseq (strand honored)
 =cut
 
 sub subseq {
    my ($self,$start,$end) = @_;
 
-   if( $start > $end ){
-       $self->throw("in subseq, start [$start] has to be greater than end [$end]");
+   if( ref($start) && $start->isa('Bio::LocationI') ) {
+       my $loc = $start;
+       if( $loc->length == 0 ) { 
+	   $self->warn("Expect location lengths to be > 0");
+	   return '';
+       } elsif( $loc->end < $loc->start ) { 
+	   # what about circular seqs
+	   $self->warn("Expect location start to come before location end");
+       }
+       my $seq = '';
+       if( $loc->isa('Bio::Location::SplitLocationI') ) {
+	   foreach my $subloc ( $loc->sub_Location ) {
+	       my $piece = substr( $self->seq(), $subloc->start - 1, 
+				   $subloc->length);
+	       if( $subloc->strand < 0 ) { 
+		   $piece = Bio::PrimarySeq->new('-seq' => 
+						 $piece)->revcom()->seq();
+	       }
+	       $seq .= $piece;
+	   }
+       } else { 
+	   $seq = substr( $self->seq(), $loc->start - 1, $loc->length);
+       }
+       if( $loc->strand < 0 ) { 
+	   $seq = Bio::PrimarySeq->new('-seq' => $seq)->revcom()->seq();
+       }
+       return $seq;
+   } 
+   elsif(  defined  $start && defined $end ) {
+       if( $start > $end ){
+	   $self->throw("in subseq, start [$start] has to be ".
+			"greater than end [$end]");
+       }
+       if( $start <= 0 || $end > $self->length ) {
+	   $self->throw("You have to have start positive \nand length less ".
+			"than the total length of sequence [$start:$end] ".
+			"Total ".$self->length."");
+       }
+
+       # remove one from start, and then length is end-start
+       $start--;
+
+       return substr $self->seq(), $start, ($end-$start);
+   } else {
+       $self->warn("Incorrect parameters to subseq - must be two integers ".
+		   "or a Bio::LocationI object not ($start,$end)");
    }
-
-   if( $start <= 0 || $end > $self->length ) {
-       $self->throw("You have to have start positive and length less than the total length of sequence [$start:$end] Total ".$self->length."");
-   }
-
-   # remove one from start, and then length is end-start
-
-   $start--;
-
-   return substr $self->seq(), $start, ($end-$start);
-
 }
 
 =head2 length
@@ -349,14 +376,16 @@ sub length {
  Usage   : $id_string = $obj->display_id();
  Function: returns the display id, aka the common name of the Sequence object.
 
-         The semantics of this is that it is the most likely string to be
-         used as an identifier of the sequence, and likely to have "human" readability.
-         The id is equivalent to the ID field of the GenBank/EMBL databanks and
-         the id field of the Swissprot/sptrembl database. In fasta format, the >(\S+)
-         is presumed to be the id, though some people overload the id to embed other
-         information. Bioperl does not use any embedded information in the ID field,
-         and people are encouraged to use other mechanisms (accession field for example,
-         or extending the sequence object) to solve this.
+           The semantics of this is that it is the most likely string to
+           be used as an identifier of the sequence, and likely to have
+           "human" readability.  The id is equivalent to the ID field of
+           the GenBank/EMBL databanks and the id field of the
+           Swissprot/sptrembl database. In fasta format, the >(\S+) is
+           presumed to be the id, though some people overload the id to
+           embed other information. Bioperl does not use any embedded
+           information in the ID field, and people are encouraged to use
+           other mechanisms (accession field for example, or extending
+           the sequence object) to solve this.
 
  Returns : A string
  Args    : None
@@ -385,8 +414,9 @@ sub display_id {
            unique id for the implemetation, allowing multiple objects
            to have the same accession number in a particular implementation.
 
-           For sequences with no accession number, this method should return
-           "unknown".
+           For sequences with no accession number, this method should
+           return "unknown".
+
  Returns : A string
  Args    : A string (optional) for setting
 
@@ -410,12 +440,13 @@ sub accession_number {
  Title   : primary_id
  Usage   : $unique_key = $obj->primary_id;
  Function: Returns the unique id for this object in this
-           implementation. This allows implementations to manage
-           their own object ids in a way the implementaiton can control
+           implementation. This allows implementations to manage their
+           own object ids in a way the implementaiton can control
            clients can expect one id to map to one object.
 
-           For sequences with no natural primary id, this method should return
-           a stringified memory location.
+           For sequences with no natural primary id, this method
+           should return a stringified memory location.
+
  Returns : A string
  Args    : A string (optional, for setting)
 
@@ -434,10 +465,10 @@ sub primary_id {
 }
 
 
-=head2 moltype
+=head2 alphabet
 
- Title   : moltype
- Usage   : if( $obj->moltype eq 'dna' ) { /Do Something/ }
+ Title   : alphabet
+ Usage   : if( $obj->alphabet eq 'dna' ) { /Do Something/ }
  Function: Returns the type of sequence being one of
            'dna', 'rna' or 'protein'. This is case sensitive.
 
@@ -452,17 +483,18 @@ sub primary_id {
 
 =cut
 
-sub moltype {
+sub alphabet {
     my ($obj,$value) = @_;
     if (defined $value) {
-	$value = lc $value; # let's just make it lowercase consistently
+	$value = lc $value;
 	unless ( $valid_type{$value} ) {
 	    $obj->throw("Molecular type '$value' is not a valid type (".
-			join(',', map "'$_'", sort keys %valid_type) .") lowercase");
+			join(',', map "'$_'", sort keys %valid_type) .
+			") lowercase");
 	}
-	$obj->{'moltype'} = $value;
+	$obj->{'alphabet'} = $value;
     }
-    return $obj->{'moltype'};
+    return $obj->{'alphabet'};
 }
 
 =head2 desc
@@ -492,7 +524,7 @@ sub desc {
  Usage   :
  Function:
  Example :
- Returns :
+ Returns : true
  Args    :
 
 
@@ -527,10 +559,10 @@ sub  id {
 }
 
 
-=head1 Methods Inherieted from Bio::PrimarySeqI
+=head1 Methods Inherited from Bio::PrimarySeqI
 
-These methods are available on Bio::PrimarySeq, although they are actually
-implemented on Bio::PrimarySeqI
+These methods are available on Bio::PrimarySeq, although they are
+actually implemented on Bio::PrimarySeqI
 
 =head2 revcom
 
@@ -578,9 +610,9 @@ These are internal methods to PrimarySeq
 
 =cut
 
-=head2 _guess_type
+=head2 _guess_alphabet
 
- Title   : _guess_type
+ Title   : _guess_alphabet
  Usage   :
  Function:
  Example :
@@ -590,16 +622,17 @@ These are internal methods to PrimarySeq
 
 =cut
 
-sub _guess_type {
+sub _guess_alphabet {
    my ($self) = @_;
    my ($str,$str2,$total,$atgc,$u,$type);
 
    $str = $self->seq();
-   $str =~ s/\-\.//g;
+   $str =~ s/\-\.\?//g;
 
    $total = CORE::length($str);
    if( $total == 0 ) {
-       $self->throw("Got a sequence with no letters in - cannot guess type [$str]");
+       $self->throw("Got a sequence with no letters in - ".
+		    "cannot guess alphabet [$str]");
    }
 
    $str2 = $str;
@@ -620,7 +653,7 @@ sub _guess_type {
        $type = 'protein';
    }
 
-   $self->moltype($type);
+   $self->alphabet($type);
 
 }
 
