@@ -1,9 +1,9 @@
 #-----------------------------------------------------------------------------
 # PACKAGE : Bio::Root::Utilities.pm
 # PURPOSE : Provides general-purpose utilities of potential interest to any Perl script.
-# AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
+# AUTHOR  : Steve Chervitz (sac@bioperl.org)
 # CREATED : Feb 1996
-# REVISION: $Id: Utilities.pm,v 1.5 1999/04/06 11:14:15 sac Exp $
+# REVISION: $Id: Utilities.pm,v 1.20 2002/01/26 20:28:13 heikki Exp $
 # STATUS  : Alpha
 #
 # This module manages file compression and uncompression using gzip or
@@ -14,7 +14,7 @@
 #
 # If you manage to incorporate an alternate compression utility into this
 # module, please post a note to the bio.perl.org mailing list
-# vsns-bcd-perl@lists.uni-bielefeld.de. Thanks.
+# bioperl-l@bioperl.org
 #
 # TODO    : Configure $GNU_PATH during installation.
 #           Improve documentation (POD).
@@ -22,31 +22,39 @@
 #
 # MODIFICATIONS: See bottom of file.
 #
-# Copyright (c) 1996-8 Steve A. Chervitz. All Rights Reserved.
+# Copyright (c) 1996-2000 Steve Chervitz. All Rights Reserved.
 #          This module is free software; you can redistribute it and/or 
 #          modify it under the same terms as Perl itself.
 #
 #-----------------------------------------------------------------------------
 
 package	Bio::Root::Utilities;
+use strict;
+
+BEGIN {
+    use vars qw($Loaded_POSIX $Loaded_IOScalar);
+    $Loaded_POSIX = 1;
+    unless( eval "require POSIX" ) {
+	$Loaded_POSIX = 0;
+    }
+}
 
 use Bio::Root::Global  qw(:data :std $TIMEOUT_SECS);
 use Bio::Root::Object  ();
 use Exporter           ();
-use POSIX;
 #use AutoLoader;
 #*AUTOLOAD = \&AutoLoader::AUTOLOAD;
 
-@ISA         = qw( Bio::Root::Object Exporter);
+use vars qw( @ISA @EXPORT_OK %EXPORT_TAGS );
+@ISA         = qw( Bio::Root::Root Exporter);
 @EXPORT_OK   = qw($Util);
 %EXPORT_TAGS = ( obj => [qw($Util)],
 		 std => [qw($Util)],);
 
-use strict;  
-use vars qw($ID $VERSION $Util $GNU_PATH);
+use vars qw($ID $VERSION $Util $GNU_PATH $DEFAULT_NEWLINE);
 
 $ID        = 'Bio::Root::Utilities';
-$VERSION   = 0.042;
+$VERSION   = 0.05;
 
 # $GNU_PATH points to the directory containing the gzip and gunzip 
 # executables. It may be required for executing gzip/gunzip 
@@ -56,6 +64,8 @@ $VERSION   = 0.042;
 $GNU_PATH  = ''; 
 #$GNU_PATH  = '/tools/gnu/bin/'; 
 
+$DEFAULT_NEWLINE = "\012";  # \n  (used if get_newline() fails for some reason)
+
 ## Static UTIL object.
 $Util = {};
 bless $Util, $ID;
@@ -128,9 +138,8 @@ User feedback is an integral part of the evolution of this and other Bioperl mod
 Send your comments and suggestions preferably to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-    http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org             - General discussion
+  http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -140,11 +149,11 @@ their resolution. Bug reports can be submitted via email or the web:
     bioperl-bugs@bio.perl.org                   
     http://bio.perl.org/bioperl-bugs/           
 
-=head1 AUTHOR
+=head1 AUTHOR 
 
-Steve A. Chervitz, sac@genome.stanford.edu
+Steve Chervitz E<lt>sac@bioperl.orgE<gt>
 
-See the L<FEEDBACK> section for where to send bug reports and comments.
+See L<the FEEDBACK section | FEEDBACK> for where to send bug reports and comments.
 
 =head1 VERSION
 
@@ -158,7 +167,7 @@ Database:
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-98 Steve A. Chervitz. All Rights Reserved.
+Copyright (c) 1997-98 Steve Chervitz. All Rights Reserved.
 This module is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
 
@@ -183,10 +192,9 @@ for documentation purposes only.
 =cut
 
 
-##########################################################################################
-##                               INSTANCE METHODS                                       ##
-##########################################################################################
-
+############################################################################
+##                 INSTANCE METHODS                                       ##
+############################################################################
 
 =head2 date_format
 
@@ -229,7 +237,7 @@ for documentation purposes only.
            :           12/1/97 (for 1 December 1997)
            :           1997-12-01 
            :           1997-Dec-01
- Throws    : Exception if the file appears to be empty or non-existent
+ Throws    : 
  Comments  : Relies on the $BASE_YEAR constant exported by Bio:Root::Global.pm.
            :
            : If you don't care about formatting or using backticks, you can
@@ -242,7 +250,7 @@ See Also   : L<file_date>(), L<month2num>()
 
 =cut
 
-#---------------
+#---------------'
 sub date_format {
 #---------------
     my $self   = shift;
@@ -257,7 +265,7 @@ sub date_format {
     my (@date);
 
     # Load a supplied date for conversion:
-    if(defined($date)) {
+    if(defined($date) && ($date =~ /[\D-]+/)) {
 	if( $date =~ /\//) {
 	    ($mon,$mday,$year) = split(/\//, $date); 
 	} elsif($date =~ /(\d{4})-(\d{1,2})-(\d{1,2})/) {
@@ -271,7 +279,8 @@ sub date_format {
 	if(length($year) == 4) { $year = substr $year, 2; }
 	$mon -= 1;
     } else {
-	($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = @date =localtime(time);
+	($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = @date =
+	    localtime(($date ? $date : time()));
 	return @date if $option =~ /list/i;
     }
     $month_txt = $MONTHS[$mon];
@@ -330,7 +339,9 @@ sub date_format {
 
 =cut
 
+#--------------'
 sub month2num {
+#--------------
 
     my ($self, $str) = @_;
 
@@ -404,7 +415,11 @@ sub compress {
     my ($compressed, @args);
 
     if($tmp or not -o $fileName) {
-	$compressed = POSIX::tmpnam;
+	if($Loaded_POSIX) {
+	    $compressed = POSIX::tmpnam;
+	} else {
+	    $compressed = _get_pseudo_tmpnam();
+	}
 	$compressed .= ".tmp.bioperl";
 	$compressed .= '.gz';
 	@args = ($GNU_PATH."gzip -f < $fileName > $compressed");
@@ -438,7 +453,7 @@ sub compress {
 
  Title     : uncompress
  Usage     : $Util->uncompress(filename, [tmp]);
- Purpose   : Uncompress a file to conserve disk space.
+ Purpose   : Uncompress a file.
  Example   : $Util->uncompress("/usr/people/me/data.txt.gz");
  Returns   : String (name of uncompressed file, full path).
  Argument  : filename = String (name of file to be uncompressed, full path).
@@ -477,7 +492,11 @@ sub uncompress {
     my($uncompressed, @args);
 
     if($tmp or not -o $fileName) {
-	$uncompressed = POSIX::tmpnam;
+	if($Loaded_POSIX) {
+	    $uncompressed = POSIX::tmpnam;
+	} else {
+	    $uncompressed = _get_pseudo_tmpnam();
+	}
 	$uncompressed .= ".tmp.bioperl";
 	@args = ($GNU_PATH."gunzip -f < $fileName > $uncompressed");
 	not $tmp and $self->verbose > 0 and
@@ -519,11 +538,7 @@ sub uncompress {
           : date_format = string, desired format for date (see date_format()).
           :               Default = yyyy-mm-dd
  Thows    : Exception if no file is provided or does not exist.
- Comments : Uses `ls -lga` to get file date data.
-          : Not so universal and not taint-safe. 
-          : Think about using stat() or a standard CPAN module for this, like
-          : Date::Manip or Date::DateCalc. However, these are pretty heavy-duty.
-          : I just want a simple function.
+ Comments : Uses the mtime field as obtained by stat().
 
 =cut
 
@@ -535,32 +550,9 @@ sub file_date {
     $self->throw("No such file: $file") if not $file or not -e $file;
 
     $fmt ||= 'yyyy-mm-dd';
-    my($fmon,$fday,$fyear);
 
-    my $file_data = `ls -lga $file`;
-    # Parsing lines such as:
-    # -rwxr-xr-x   1 sac      sac          7028 Nov  5  1997 ./YDR222W.blastp
-    # -rwxrwxr-x   1 sac      sac           525 Jun 23 16:20 ./utilities.p
-    if($file_data =~ / ([a-z]{3})  ?([\d]{1,2})  ?([\d:]+) /i) {
-	($fmon,$fday,$fyear) = ($1, $2, $3);
-    } else {
-	# If the regexp fails, split().
-	my @file_data = split /\s+/, $file_data;
-	($fmon,$fday,$fyear) = @file_data[5..7];
-    }
-
-    if($fyear =~ /:/) { $fyear = $self->date_format('year'); }
-    my $fmon_num = '00';
-    foreach(0..11) { if($MONTHS[$_] eq $fmon) {$fmon_num = $_ + 1; last;} }
-
-    my $date = sprintf "%4d-%02d-%02d",$fyear,$fmon_num,$fday;
-
-    if($fmt =~ /yyyy-mmm-dd/i ) {
-	$date = sprintf "%4d-%3s-%02d",$fyear,$fmon,$fday;
-    } elsif($fmt eq 'd m y' ) {
-	$date = sprintf "%s %s %s",$fday,$fmon,$fyear;
-    }
-    $date;
+    my @file_data = stat($file);
+    return $self->date_format($fmt, $file_data[9]); # mtime field
 }
 
 
@@ -587,7 +579,7 @@ sub file_date {
 
 =cut
 
-#------------	
+#------------`
 sub untaint {
 #------------	
     my($self,$value,$relax) = @_;
@@ -615,32 +607,6 @@ sub untaint {
 }
 
 
-=head2 is_tainted
-
- Title  : is_tainted
- Purpose: Test whether a variable is tainted or not.
-        : Used for testing variables for taintedness. 
-        : Development use only. 
- Usage  : $Util->is_tainted($string);
- Warning: This method  always generates a compile-time
-        : warning and is therefore commented out.
-
-=cut
-
-#--------------
-sub is_tainted {
-#--------------
-#    my $self = shift;
-#    local($^W) = 0;    ## disable warnings with -w (run-time only)
-#    # Test for tained data. See the Camel book 2ed, p.358.
-#    not eval {
-#	  join("",@_), kill 0;
-#	  1;
-#    };
-}
-
-
-
 =head2 mean_stdev
 
  Title    : mean_stdev
@@ -805,7 +771,7 @@ sub delete {
            : this method should probably have a -mode parameter to
            : specify ascii or binary.
 
-See Also :  L<get_newline>(), L<Bio::Root:IOManager::read>(),
+See Also :  L<get_newline>(), L<Bio::Root::IOManager::read>(),
 
 =cut
 
@@ -816,9 +782,11 @@ sub create_filehandle {
     my($client, $file, $handle) =
 	$self->_rearrange([qw( CLIENT FILE HANDLE )], @param);
 
-    if(not $client) {  $client = $self; }
+    if(not ref $client) {  $client = $self; }
     $file ||= $handle;
-    $file = $client->file($file);
+    if( $client->can('file')) {
+	$file = $client->file($file);
+    }
 
     my $FH; # = new FileHandle;
 
@@ -829,7 +797,6 @@ sub create_filehandle {
 	$FH = $file;
 	$client->{'_input_type'} = "FileHandle";
       } elsif($handle_ref eq 'GLOB') {
-#	$FH = new FileHandle($file);  # Can't do this
 	$FH = $file;
 	$client->{'_input_type'} = "Glob";
       } else {
@@ -888,12 +855,11 @@ sub get_newline {
 
     my $FH = $self->create_filehandle(@param);
 
-    if(not $client) {  $client = $self;   }
+    if(not ref $client) {  $client = $self;   }
 
-    if($client->{'_input_type'} eq 'STDIN' ||
-      $client->{'_input_type'} =~ /compressed/ ) {
+    if($client->{'_input_type'} =~ /STDIN|Glob|compressed/) {
       # Can't taste from STDIN since we can't seek 0 on it.
-      # Are other non special Glob refs seek able?
+      # Are other non special Glob refs seek-able? 
       # Attempt to guess newline based on platform.
       # Not robust since we could be reading Unix files on a Mac, e.g.
       if(defined $ENV{'MACPERL'}) {
@@ -905,11 +871,13 @@ sub get_newline {
       $NEWLINE = $self->taste_file($FH);
     }
 
-    close ($FH) unless $client->{'_input_type'} eq 'STDIN';
+    close ($FH) unless ($client->{'_input_type'} eq 'STDIN' || 
+                        $client->{'_input_type'} eq 'FileHandle' ||
+                        $client->{'_input_type'} eq 'Glob' );
     
     delete $client->{'_input_type'};
 
-    return $NEWLINE;
+    return $NEWLINE || $DEFAULT_NEWLINE;
   }
 
 
@@ -944,12 +912,24 @@ sub taste_file {
   ref($FH) eq 'FileHandle' or $self->throw("Can't taste file: not a FileHandle ref");
 
   $buffer = '';
+
+  # this is a quick hack to check for availability of alarm(); just copied
+  # from Bio/Root/IOManager.pm HL 02/19/01
+  my $alarm_available = 1;
+  eval {
+      alarm(0);
+  };
+  if($@) {
+      # alarm() not available (ActiveState perl for win32 doesn't have it.
+      # See jitterbug PR#98)
+      $alarm_available = 0;
+  }
   $SIG{ALRM} = sub { die "Timed out!"; };
   my $result;
   eval {
-    alarm( $wait );
+    $alarm_available && alarm( $wait );
     $result = read($FH, $buffer, $BUFSIZ); # read the $BUFSIZ characters of file
-    alarm(0);
+    $alarm_available && alarm(0);
   };
   if($@ =~ /Timed out!/) {
     $self->throw("Timed out while waiting for input.", 
@@ -1051,7 +1031,7 @@ See Also  : L<mail_authority>()
 =cut
 
 
-#-------------
+#-------------'
 sub send_mail {
 #-------------
     my( $self, @param) = @_;
@@ -1168,6 +1148,23 @@ sub verify_version {
     }
 }
 
+# Purpose : Returns a string that can be used as a temporary file name.
+#           Based on localtime.
+#           This is used if POSIX is not available.
+
+sub _get_pseudo_tmpnam {
+
+    my $date = localtime(time());
+    
+    my $tmpnam = 'tmpnam'; 
+
+    if( $date =~ /([\d:]+)\s+(\d+)\s*$/ ) {
+    	$tmpnam = $2. '_' . $1;
+    	$tmpnam =~ s/:/_/g;
+    }
+    return $tmpnam;
+}
+
 
 1;
 __END__
