@@ -1,4 +1,4 @@
-# $Id: SeqFeatureI.pm,v 1.22.2.1 2001/03/02 22:47:54 heikki Exp $
+# $Id: SeqFeatureI.pm,v 1.27 2001/12/28 08:00:01 sac Exp $
 #
 # BioPerl module for Bio::SeqFeatureI
 #
@@ -18,7 +18,7 @@ Bio::SeqFeatureI - Abstract interface of a Sequence Feature
 
     # get a seqfeature somehow, eg,
 
-    foreach $feat ( $annseq->all_seqfeatures() ) {
+    foreach $feat ( $annseq->all_SeqFeatures() ) {
             print "Feature from ", $feat->start, "to ", 
 	          $feat->end, " Primary tag  ", $feat->primary_tag, 
 	          ", produced by ", $feat->source_tag(), "\n";
@@ -40,11 +40,12 @@ Bio::SeqFeatureI - Abstract interface of a Sequence Feature
 
 =head1 DESCRIPTION
 
-This interface is the functions one can expect for any Sequence Feature, whatever
-its implemtation or whether it is a more complex type (eg, a Gene). This object
-doesn't actually provide any implemention, it just provides the definitions
-of what methods one can call. See Bio::SeqFeature::Generic for a good standard
-implementation of this object
+This interface is the functions one can expect for any Sequence
+Feature, whatever its implemtation or whether it is a more complex
+type (eg, a Gene). This object doesn\'t actually provide any
+implemention, it just provides the definitions of what methods one can
+call. See Bio::SeqFeature::Generic for a good standard implementation
+of this object
 
 =head1 FEEDBACK
 
@@ -71,7 +72,6 @@ methods. Internal methods are usually preceded with a _
 
 =cut
 
-#'
 
 # Let the code begin...
 
@@ -80,25 +80,15 @@ package Bio::SeqFeatureI;
 use vars qw(@ISA);
 use strict;
 
-# Object preamble - inheriets from Bio::Root::Object
 use Bio::RangeI;
 
 use Carp;
 
 @ISA = qw(Bio::RangeI);
 
+=head2 Bio::RangeI methods
 
-# utility method Prints out a method like: 
-# Abstract method stop defined in interface Bio::SeqFeatureI not
-# implemented by package You::BadFeature
-
-sub _abstractDeath {
-  my $self = shift;
-  my $package = ref $self;
-  my $caller = (caller)[1];
-  
-  confess "Abstract method '$caller' defined in interface Bio::SeqFeatureI not implemented by pacakge $package";
-}
+List of interfaces inherited from  L<Bio::RangeI>.
 
 =head2 start
 
@@ -109,14 +99,6 @@ sub _abstractDeath {
  Args    : none
 
 
-=cut
-
-sub start{
-   my ($self,@args) = @_;
-
-   $self->_abstractDeath();
-}
-
 =head2 end
 
  Title   : end
@@ -125,17 +107,6 @@ sub start{
  Returns : integer
  Args    : none
 
-
-=cut
-
-sub end{
-   my ($self,@args) = @_;
-
-   $self->_abstractDeath();
-
-}
-
-
 =head2 strand
 
  Title   : strand
@@ -147,12 +118,9 @@ sub end{
 
 =cut
 
-sub strand{
-   my ($self,@args) = @_;
+=head2 SeqFeatureI specific methods
 
-   $self->_abstractDeath();
-
-}
+New method interfaces.
 
 =head2 sub_SeqFeature
 
@@ -168,7 +136,7 @@ sub strand{
 sub sub_SeqFeature{
    my ($self,@args) = @_;
 
-   $self->_abstractDeath();
+   $self->throw_not_implemented();
 }
 
 
@@ -187,7 +155,7 @@ sub sub_SeqFeature{
 sub primary_tag{
    my ($self,@args) = @_;
 
-   $self->_abstractDeath();
+   $self->throw_not_implemented();
 
 }
 
@@ -206,8 +174,7 @@ sub primary_tag{
 sub source_tag{
    my ($self,@args) = @_;
 
-   $self->_abstractDeath();
-
+   $self->throw_not_implemented();
 }
 
 =head2 has_tag
@@ -224,7 +191,7 @@ sub source_tag{
 sub has_tag{
    my ($self,@args) = @_;
 
-   $self->_abstractDeath();
+   $self->throw_not_implemented();
 
 }
 
@@ -242,7 +209,7 @@ sub has_tag{
 sub each_tag_value {
    my ($self,@args) = @_;
 
-   $self->_abstractDeath();
+   $self->throw_not_implemented();
 }
 
 =head2 all_tags
@@ -259,8 +226,7 @@ sub each_tag_value {
 sub all_tags{
    my ($self,@args) = @_;
 
-   $self->_abstractDeath();
-
+   $self->throw_not_implemented();
 }
 
 =head2 gff_string
@@ -311,7 +277,6 @@ sub _static_gff_formatter{
    if( !defined $static_gff_formatter ) {
        $static_gff_formatter = Bio::Tools::GFF->new('-gff_version' => 2);
    }
-
    return $static_gff_formatter;
 }
 
@@ -391,7 +356,7 @@ triplets (start, stop, strand) from which new ranges could be built.
 sub location {
    my ($self) = @_;
 
-   $self->_abstractDeath();
+   $self->throw_not_implemented();
 }
 
 
