@@ -1,5 +1,6 @@
+
 #
-# BioPerl module for Bio::Pfam::Annotation::Comment
+# BioPerl module for Bio::Species
 #
 # Cared for by James Gilbert <jgrg@sanger.ac.uk>
 #
@@ -13,21 +14,22 @@ Bio::Species - Generic species object
 
 =head1 SYNOPSIS
 
-    $species = Bio::Species->new(); # Can also pass classification
+    $species = Bio::Species->new(-classification => [@classification]);
+                                    # Can also pass classification
                                     # array to new as below
-                                    
+
     $species->classification(qw( sapiens Homo Hominidae
                                  Catarrhini Primates Eutheria
                                  Mammalia Vertebrata Chordata
                                  Metazoa Eukaryota ));
-    
+
     $genus = $species->genus();
-    
+
     $bi = $species->binomial();     # $bi is now "Homo sapiens"
-    
+
     # For storing common name
     $species->common_name("human");
-    
+
     # For storing subspecies
     $species->sub_species("accountant");
 
@@ -37,7 +39,7 @@ Provides a very simple object for storing phylogenetic
 information.  The classification is stored in an array,
 which is a list of nodes in a phylogenetic tree.  Access to
 getting and setting species and genus is provided, but not
-to any of the other node types (eg: "phlum", "class",
+to any of the other node types (eg: "phylum", "class",
 "order", "family").  There's plenty of scope for making the
 model more sophisticated, if this is ever needed.
 
@@ -55,32 +57,34 @@ methods. Internal methods are usually preceded with a _
 
 =cut
 
+
 #' Let the code begin...
 
+
 package Bio::Species;
 use vars qw(@ISA);
 use strict;
 
-# Object preamble - inheriets from Bio::Root::Object
+# Object preamble - inherits from Bio::Root::Object
 
-use Bio::Root::Object;
+use Bio::Root::Root;
 
-@ISA = qw(Bio::Root::Object);
-# new() is inherited from Bio::Root::Object
 
-# _initialize is where the heavy stuff will happen when new is called
+@ISA = qw(Bio::Root::Root);
 
-sub _initialize {
-  my($self,@args) = @_;
+sub new {
+  my($class,@args) = @_;
 
-  my $make = $self->SUPER::_initialize;
+  my $self = $class->SUPER::new(@args);
 
   $self->{'classification'} = [];
   $self->{'common_name'} = undef;
-  if (@args) {
-    $self->classification(@args);
+  my ($classification) = $self->_rearrange([qw(CLASSIFICATION)], @args);
+  if( defined $classification &&
+      (ref($classification) =~ /array/i) ) {
+      $self->classification(@$classification);
   }
-  return $make; # success - we hope!
+  return $self;
 }
 
 =head2 classification
@@ -88,7 +92,7 @@ sub _initialize {
  Title   : classification
  Usage   : $self->classification(@class_array);
            @classification = $self->classification();
- Function: Fills or returns the classifcation list in
+ Function: Fills or returns the classification list in
            the object.  The array provided must be in
            the order SPECIES, GENUS ---> KINGDOM.
            Checks are made that species is in lower case,
@@ -101,36 +105,36 @@ sub _initialize {
 
 =cut
 
-sub classification {
-    my $self = shift;
 
-    if (@_) {
-        my @classification = @_;
-        
+
+sub classification {
+    my ($self,@args) = @_;
+
+    if (@args) {
+
         # Check the names supplied in the classification string
         {
             # Species should be in lower case
-            my $species = $classification[0];
+            my $species = $args[0];
             $self->validate_species_name( $species );
 
             # All other names must be in title case
-            for (my $i = 1; $i < @classification; $i++) {
-                $self->validate_name( $classification[$i] );
+            for (my $i = 1; $i < @args; $i++) {
+                $self->validate_name( $args[$i] );
             }
         }
-
         # Store classification
-        $self->{'classification'} = [ @classification ];
+        $self->{'classification'} = [ @args ];
     }
     return @{$self->{'classification'}};
 }
 
-=head2 
+=head2 common_name
 
  Title   : common_name
  Usage   : $self->common_name( $common_name );
            $common_name = $self->common_name();
- Function: Get or set the commonn name of the species
+ Function: Get or set the common name of the species
  Example : $self->common_name('human')
  Returns : The common name in a string
  Args    : String, which is the common name
@@ -139,14 +143,14 @@ sub classification {
 
 sub common_name {
     my($self, $name) = @_;
-    
+
     if ($name) {
         $self->{'common_name'} = $name;
     } else {
-        return $self->{'common_name'} 
+        return $self->{'common_name'}
     }
 }
-=head2 
+=head2
 
  Title   : organelle
  Usage   : $self->organelle( $organelle );
@@ -160,11 +164,11 @@ sub common_name {
 
 sub organelle {
     my($self, $name) = @_;
-    
+
     if ($name) {
         $self->{'organelle'} = $name;
     } else {
-        return $self->{'organelle'} 
+        return $self->{'organelle'}
     }
 }
 
@@ -181,9 +185,10 @@ sub organelle {
 
 =cut
 
+
 sub species {
     my($self, $species) = @_;
-    
+
     if ($species) {
         $self->validate_species_name( $species );
         $self->{'classification'}[0] = $species;
@@ -204,9 +209,10 @@ sub species {
 
 =cut
 
+
 sub genus {
     my($self, $genus) = @_;
-    
+
     if ($genus) {
         $self->validate_name( $genus );
         $self->{'classification'}[1] = $genus;
@@ -218,10 +224,11 @@ sub genus {
 
  Title   : sub_species
  Usage   : $obj->sub_species($newval)
- Function: 
+ Function:
  Returns : value of sub_species
  Args    : newvalue (optional)
 
+
 =cut
 
 sub sub_species {
@@ -245,10 +252,16 @@ sub sub_species {
 
 =cut
 
+
 sub binomial {
     my( $self, $full ) = @_;
-    
+
     my( $species, $genus ) = $self->classification();
+    unless( defined $species) {
+	$species = '';
+	$self->warn("classification was not set");
+    }
+    $genus = ''   unless( defined $genus);
     my $bi = "$genus $species";
     if (defined($full) && ($full eq 'FULL')) {
 	my $ssp = $self->sub_species;
@@ -259,18 +272,38 @@ sub binomial {
 
 sub validate_species_name {
     my( $self, $string ) = @_;
-    
+
     $string =~ /^[\S\d\.]+$||""/ or
         $self->throw("Invalid species name '$string'");
 }
 
 sub validate_name {
     my( $self, $string ) = @_;
-    
+
     return $string =~ /^[A-Z][a-z]+$/ or
         $self->throw("Invalid name '$string' (Wrong case?)");
 }
 
+=head2 ncbi_taxid
+
+ Title   : ncbi_taxid
+ Usage   : $obj->ncbi_taxid($newval)
+ Function:
+ Returns : value of ncbi_taxid as string
+ Args    : newvalue (optional)
+
+
+=cut
+
+sub ncbi_taxid {
+    my( $self, $sub ) = @_;
+
+    if ($sub) {
+        $self->{'_ncbi_taxid'} = $sub;
+    }
+    return $self->{'_ncbi_taxid'};
+}
+
 1;
 
 __END__
