@@ -1,4 +1,4 @@
-# $Id: CodonTable.pm,v 1.12.2.3 2001/11/14 11:26:55 birney Exp $
+# $Id: CodonTable.pm,v 1.22 2001/12/13 23:09:51 jason Exp $
 #
 # bioperl module for Bio::Tools::CodonTable
 #
@@ -57,7 +57,6 @@ since that is what they try to represent. A bit more complete picture
 of the full complexity of codon usage in various taxonomic groups
 presented at the NCBI Genetic Codes Home page.
 
-
 CodonTable is a BioPerl class that knows all current translation
 tables that are used by primary nucleotide sequence databases
 (GenBank, EMBL and DDBJ). It provides methods to output information
@@ -72,9 +71,10 @@ acid transcripts. The CodonTable object accepts codons of both type as
 input and allows the user to set the mode for output when reverse
 translating. Its default for output is DNA.
 
-Note: This class deals with individual codons and amino acids, only.
-      Call it from your own objects to translate and reverse translate
-      longer sequences.
+Note: This class deals primarily with individual codons and amino
+      acids. However in the interest of speed you can L<translate>
+      longer sequence, too. The full complexity of protein translation
+      is tackled by L<Bio::PrimarySeqI::translate>.
 
 
 The amino acid codes are IUPAC recommendations for common amino acids:
@@ -161,153 +161,110 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Tools::CodonTable;
-use vars qw(@ISA);
+use vars qw(@ISA @NAMES @TABLES @STARTS $TRCOL $CODONS %IUPAC_DNA 
+	    %IUPAC_AA %THREELETTERSYMBOLS $VALID_PROTEIN $TERMINATOR);
 use strict;
 
-# Object preamble - inherits from Bio::Root::RootI
-use Bio::Root::RootI;
-@ISA = qw(Bio::Root::RootI);
+# Object preamble - inherits from Bio::Root::Root
+use Bio::Root::Root;
+use Bio::Tools::IUPAC;
+use Bio::SeqUtils;
+
+@ISA = qw(Bio::Root::Root);
 
-{
 # first set internal values for all translation tables
 
-my @names =  #id
-    (
-     'Standard', #1
-     'Vertebrate Mitochondrial',#2
-     'Yeast Mitochondrial',# 3
-     'Mold, Protozoan, and CoelenterateMitochondrial and Mycoplasma/Spiroplasma',#4
-     'Invertebrate Mitochondrial',#5
-     'Ciliate, Dasycladacean and Hexamita Nuclear',# 6
-       '', '',
-     'Echinoderm Mitochondrial',#9
-     'Euplotid Nuclear',#10
-     '"Bacterial"',# 11
-     'Alternative Yeast Nuclear',# 12
-     'Ascidian Mitochondrial',# 13
-     'Flatworm Mitochondrial',# 14
-     'Blepharisma Nuclear',# 15
-     'Chlorophycean Mitochondrial',# 16
-       '', '',  '', '',
-     'Trematode Mitochondrial',# 21
-     'Scenedesmus obliquus Mitochondrial', #22
-     'Thraustochytrium Mitochondrial' #23
-     );
+BEGIN { 
+    @NAMES =			#id
+	(
+	 'Standard',		#1
+	 'Vertebrate Mitochondrial',#2
+	 'Yeast Mitochondrial',# 3
+	 'Mold, Protozoan, and CoelenterateMitochondrial and Mycoplasma/Spiroplasma',#4
+	 'Invertebrate Mitochondrial',#5
+	 'Ciliate, Dasycladacean and Hexamita Nuclear',# 6
+	 '', '',
+	 'Echinoderm Mitochondrial',#9
+	 'Euplotid Nuclear',#10
+	 '"Bacterial"',# 11
+	 'Alternative Yeast Nuclear',# 12
+	 'Ascidian Mitochondrial',# 13
+	 'Flatworm Mitochondrial',# 14
+	 'Blepharisma Nuclear',# 15
+	 'Chlorophycean Mitochondrial',# 16
+	 '', '',  '', '',
+	 'Trematode Mitochondrial',# 21
+	 'Scenedesmus obliquus Mitochondrial', #22
+	 'Thraustochytrium Mitochondrial' #23
+	 );
 
-my @tables =
-    qw(
-       FFLLSSSSYY**CC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
-       FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIMMTTTTNNKKSS**VVVVAAAADDEEGGGG
-       FFLLSSSSYY**CCWWTTTTPPPPHHQQRRRRIIMMTTTTNNKKSSRRVVVVAAAADDEEGGGG
-       FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
-       FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIMMTTTTNNKKSSSSVVVVAAAADDEEGGGG
-       FFLLSSSSYYQQCC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
-       '' ''
-       FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIIMTTTTNNNKSSSSVVVVAAAADDEEGGGG
-       FFLLSSSSYY**CCCWLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
-       FFLLSSSSYY**CC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
-       FFLLSSSSYY**CC*WLLLSPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
-       FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIMMTTTTNNKKSSGGVVVVAAAADDEEGGGG
-       FFLLSSSSYYY*CCWWLLLLPPPPHHQQRRRRIIIMTTTTNNNKSSSSVVVVAAAADDEEGGGG
-       FFLLSSSSYY*QCC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
-       FFLLSSSSYY*LCC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
-       '' '' '' ''
-       FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIMMTTTTNNNKSSSSVVVVAAAADDEEGGGG   
-       FFLLSS*SYY*LCC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
-       FF*LSSSSYY**CC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
-       );
+    @TABLES =
+	qw(
+	   FFLLSSSSYY**CC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+	   FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIMMTTTTNNKKSS**VVVVAAAADDEEGGGG
+	   FFLLSSSSYY**CCWWTTTTPPPPHHQQRRRRIIMMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+	   FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+	   FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIMMTTTTNNKKSSSSVVVVAAAADDEEGGGG
+	   FFLLSSSSYYQQCC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+	   '' ''
+	   FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIIMTTTTNNNKSSSSVVVVAAAADDEEGGGG
+	   FFLLSSSSYY**CCCWLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+	   FFLLSSSSYY**CC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+	   FFLLSSSSYY**CC*WLLLSPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+	   FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIMMTTTTNNKKSSGGVVVVAAAADDEEGGGG
+	   FFLLSSSSYYY*CCWWLLLLPPPPHHQQRRRRIIIMTTTTNNNKSSSSVVVVAAAADDEEGGGG
+	   FFLLSSSSYY*QCC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+	   FFLLSSSSYY*LCC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+	   '' '' '' ''
+	   FFLLSSSSYY**CCWWLLLLPPPPHHQQRRRRIIMMTTTTNNNKSSSSVVVVAAAADDEEGGGG   
+	   FFLLSS*SYY*LCC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+	   FF*LSSSSYY**CC*WLLLLPPPPHHQQRRRRIIIMTTTTNNKKSSRRVVVVAAAADDEEGGGG
+	   );
 
 
-my @starts =
-    qw(
-       ---M---------------M---------------M----------------------------
-       --------------------------------MMMM---------------M------------
-       ----------------------------------MM----------------------------
-       --MM---------------M------------MMMM---------------M------------
-       ---M----------------------------MMMM---------------M------------
-       -----------------------------------M----------------------------
-       '' ''
-       -----------------------------------M----------------------------
-       -----------------------------------M----------------------------
-       ---M---------------M------------MMMM---------------M------------
-       -------------------M---------------M----------------------------
-       -----------------------------------M----------------------------
-       -----------------------------------M----------------------------
-       -----------------------------------M----------------------------
-       -----------------------------------M----------------------------
-       '' ''  '' ''
-       -----------------------------------M---------------M------------  
-       -----------------------------------M----------------------------
-       --------------------------------M--M---------------M------------
-       );
+    @STARTS =
+	qw(
+	   ---M---------------M---------------M----------------------------
+	   --------------------------------MMMM---------------M------------
+	   ----------------------------------MM----------------------------
+	   --MM---------------M------------MMMM---------------M------------
+	   ---M----------------------------MMMM---------------M------------
+	   -----------------------------------M----------------------------
+	   '' ''
+	   -----------------------------------M----------------------------
+	   -----------------------------------M----------------------------
+	   ---M---------------M------------MMMM---------------M------------
+	   -------------------M---------------M----------------------------
+	   -----------------------------------M----------------------------
+	   -----------------------------------M----------------------------
+	   -----------------------------------M----------------------------
+	   -----------------------------------M----------------------------
+	   '' ''  '' ''
+	   -----------------------------------M---------------M------------  
+	   -----------------------------------M----------------------------
+	   --------------------------------M--M---------------M------------
+	   );
 
-
-my @nucs = qw(t c a g);
-my ($x) = 0;
-my ($i, $j, $k);
-my ($codons, $trCol);
-
-for ($i=0;$i<4;$i++) {
-    for ($j=0;$j<4;$j++) {
-	for ($k=0;$k<4;$k++) {
-	    $codons->{$nucs[$i]. $nucs[$j]. $nucs[$k]} = $x;
-	    $trCol->{$x} = $nucs[$i]. $nucs[$j]. $nucs[$k];
-	    $x++;
+    my @nucs = qw(t c a g);
+    my $x = 0;
+    ($CODONS, $TRCOL) = ({}, {});
+    for my $i (@nucs) {
+	for my $j (@nucs) {
+	    for my $k (@nucs) {
+		my $codon = "$i$j$k";
+		$CODONS->{$codon} = $x;
+		$TRCOL->{$x} = $codon;
+		$x++;
+	    }
 	}
     }
+    %IUPAC_DNA = Bio::Tools::IUPAC->iupac_iub();    
+    %IUPAC_AA = Bio::Tools::IUPAC->iupac_iup();
+    %THREELETTERSYMBOLS = Bio::SeqUtils->valid_aa(2);
+    $VALID_PROTEIN = '['.join('',Bio::SeqUtils->valid_aa(0)).']';
+    $TERMINATOR = '*';
 }
 
-my  %onecode =
-    ('Ala' => 'A',     'Asx' => 'B',
-     'Cys' => 'C',     'Asp' => 'D',
-     'Glu' => 'E',     'Phe' => 'F',
-     'Gly' => 'G',     'His' => 'H',
-     'Ile' => 'I',     'Lys' => 'K',
-     'Leu' => 'L',     'Met' => 'M',
-     'Asn' => 'N',     'Pro' => 'P',
-     'Gln' => 'Q',     'Arg' => 'R',
-     'Ser' => 'S',     'Thr' => 'T',
-     'Val' => 'V',     'Trp' => 'W',
-     'Xaa' => 'X',     'Tyr' => 'Y',
-     'Glx' => 'Z',     'Ter' => '*'
-     );
-
-my %iupac_dna =
-    ( 'a' => [qw( a       )],
-      'c' => [qw( c       )],
-      'g' => [qw( g       )],
-      't' => [qw( t       )],
-      'u' => [qw( t       )],
-      'm' => [qw( a c     )],
-      'r' => [qw( a g     )],
-      'w' => [qw( a t     )],
-      'k' => [qw( g t     )],
-      'y' => [qw( c t     )],
-      's' => [qw( c g     )],
-      'v' => [qw( a c g   )],
-      'h' => [qw( a c t   )],
-      'd' => [qw( a g t   )],
-      'b' => [qw( c g t   )],
-      'n' => [qw( a c g t )],
-      'x' => [qw( a c g t )],
-     );
-
-my %iupac_aa =
-    ( A => [qw(A)],      B => [qw(D N)],
-      C => [qw(C)],      D => [qw(D)],
-      E => [qw(E)],      F => [qw(F)],
-      G => [qw(G)],      H => [qw(H)],
-      I => [qw(I)],      K => [qw(K)],
-      L => [qw(L)],      M => [qw(M)],
-      N => [qw(N)],      P => [qw(P)],
-      Q => [qw(Q)],      R => [qw(R)],
-      S => [qw(S)],      T => [qw(T)],
-      U => [qw(U)],      V => [qw(V)],
-      W => [qw(W)],      X => [qw(X)],
-      Y => [qw(Y)],      Z => [qw(E Q)],
-      '*' => ['*']
-      );
-
 sub new {
     my($class,@args) = @_;
     my $self = $class->SUPER::new(@args);
@@ -322,7 +279,6 @@ sub new {
     return $self; # success - we hope!
 }
 
-
 =head2 id
 
  Title   : id
@@ -344,7 +300,7 @@ sub new {
 sub id{
    my ($self,$value) = @_;
    if( defined $value) {
-       if (  !(defined $tables[$value-1]) or $tables[$value-1] eq '') {
+       if (  !(defined $TABLES[$value-1]) or $TABLES[$value-1] eq '') {
 	   $self->warn("Not a valid codon table ID [$value] ");
 	   $value = 0;
        }
@@ -369,16 +325,15 @@ sub name{
    my ($self) = @_;
 
    my ($id) = $self->{'id'};
-   return $names[$id-1];
-
+   return $NAMES[$id-1];
 }
 
-
 =head2 translate
 
  Title   : translate
  Usage   : $obj->translate('YTR')
- Function: Returns one letter amino acid code for a codon input.
+ Function: Returns a string of one letter amino acid codes from 
+           nucleotide sequence input. The imput can be of any length.
 
            Returns 'X' for unknown codons and codons that code for
            more than one amino acid. Returns an empty string if input
@@ -397,56 +352,83 @@ sub name{
            three characters long.
 
  Example :
- Returns : One letter ambiguous IUPAC amino acid code
- Args    : a codon = a three character, ambiguous IUPAC nucleotide string
+ Returns : a string of one letter ambiguous IUPAC amino acid codes
+ Args    : ambiguous IUPAC nucleotide string
 
 
 =cut
 
-sub translate{
-   my ($self, $value) = @_;
-   my ($id) = $self->{'id'};
-   my ($partial) = 0;
-   my $result;
+sub translate {
+    my ($self, $seq) = @_;
+    $self->throw("Calling translate without a seq argument!") unless defined $seq;
+    return '' unless $seq;
 
-   $value  = lc $value;
-   $value  =~ tr/u/t/;
+    my $id = $self->id;
+    my ($partial) = 0;
+    $partial = 2 if length($seq) % 3 == 2;
+    
+    $seq = lc $seq; 
+    $seq =~ tr/u/t/;
+    my $protein = "";
+    if ($seq =~ /[^actg]/ ) { #ambiguous chars
+        for (my $i = 0; $i < (length($seq) - 2 ); $i+=3) {
+            my $triplet = substr($seq, $i, 3);
+	    if (exists $CODONS->{$triplet}) {
+		$protein .= substr($TABLES[$id-1], 
+				   $CODONS->{$triplet},1);
+	    } else {
+		$protein .= $self->_translate_ambiguous_codon($triplet);
+	    }
+	}
+    } else { # simple, strict translation
+	for (my $i = 0; $i < (length($seq) - 2 ); $i+=3) {
+            my $triplet = substr($seq, $i, 3); 
+            if (exists $CODONS->{$triplet}) {
+                $protein .= substr($TABLES[$id-1], $CODONS->{$triplet}, 1);
+	    } else {
+                $protein .= 'X';
+            }
+        }
+    }
+    if ($partial == 2) { # 2 overhanging nucleotides
+	my $triplet = substr($seq, ($partial -4)). "n";
+	if (exists $CODONS->{$triplet}) {
+	    my $aa = substr($TABLES[$id-1], $CODONS->{$triplet},1);       
+	    $protein .= $aa;
+	} else {
+	    $protein .= $self->_translate_ambiguous_codon($triplet, $partial);
+	}
+    }
+    return $protein;
+}
 
-   if (length $value != 3 and length $value != 2) {
-       return '';
-   }
-   elsif ($value =~ /[^atgc]/i or length $value == 2 ) {
-       if (length $value == 2 ) {
-	   $value = $value. 'n';
-	   $partial = 1;
-       }
-       my @codons = _unambiquous_codons($value);
-
-       my %aas =();
-       foreach my $codon (@codons) {
-	   $aas{substr($tables[$id-1],$codons->{$codon},1)} = 1;	
-       }
-       #foreach my $x (keys %aas) {print "$x\n";} ###
-
-       my $count = scalar keys %aas;
-       if ( $count == 1 ) {
-	   return (keys %aas)[0];
-       }
-       elsif ( $count == 2 ) {
-	   if ($aas{'D'} and $aas{'N'}) {
-	       return 'B';
-	   }
-	   elsif ($aas{'E'} and $aas{'Q'}) {
-	       return 'Z';
-	   } else {
-	       $partial ? return '' :  return 'X';
-	   }
-       } else {
-	   $partial ? return '' :  return 'X';
-       }
-   } else {
-       return translate_strict (@_);
-   }
+sub _translate_ambiguous_codon {
+    my ($self, $triplet, $partial) = @_;
+    $partial ||= 0;
+    my $id = $self->id;
+    my $aa;
+    my @codons = _unambiquous_codons($triplet);
+    my %aas =();
+    foreach my $codon (@codons) {
+	$aas{substr($TABLES[$id-1],$CODONS->{$codon},1)} = 1;
+    }
+    my $count = scalar keys %aas;
+    if ( $count == 1 ) {
+	$aa = (keys %aas)[0];
+    }
+    elsif ( $count == 2 ) {
+	if ($aas{'D'} and $aas{'N'}) {
+	    $aa = 'B';
+	}
+	elsif ($aas{'E'} and $aas{'Q'}) {
+	    $aa = 'Z';
+	} else {
+	    $partial ? ($aa = '') : ($aa = 'X');
+	}
+    } else {
+	$partial ? ($aa = '') :  ($aa = 'X');
+    }
+    return $aa;
 }
 
 =head2 translate_strict
@@ -480,11 +462,11 @@ sub translate_strict{
    if (length $value != 3 ) {
        return '';
    }
-   elsif (!(defined $codons->{$value}))  {
+   elsif (!(defined $CODONS->{$value}))  {
        return 'X';
    }
    else {
-       return substr($tables[$id-1],$codons->{$value},1);
+       return substr($TABLES[$id-1],$CODONS->{$value},1);
    }
 }
 
@@ -519,17 +501,18 @@ sub revtranslate {
     if (length($value) == 3 ) {
 	$value = lc $value;
 	$value = ucfirst $value;
-	$value = $onecode{$value};
+	$value = $THREELETTERSYMBOLS{$value};
     }
-    if ( defined $value and $value =~ /[ARNDCQEGHILKMFPSTWYVBZX*]/ and length($value) == 1 ) {
+    if ( defined $value and $value =~ /$VALID_PROTEIN/ 
+	 and length($value) == 1 ) {
 	$value = uc $value;
-	@aas = @ {$iupac_aa{$value}} ;	
+	@aas = @{$IUPAC_AA{$value}};	
 	foreach my $aa (@aas) {
 	    #print $aa, " -2\n";
 	    $aa = '\*' if $aa eq '*';
-	    while ($tables[$id-1] =~ m/$aa/g) {
-		$p = pos $tables[$id-1];
-		push (@codons, $trCol->{--$p});
+	    while ($TABLES[$id-1] =~ m/$aa/g) {
+		$p = pos $TABLES[$id-1];
+		push (@codons, $TRCOL->{--$p});
 	    }
 	}
     }
@@ -568,7 +551,7 @@ sub is_start_codon{
    }
    else {
        my $result = 1;
-       my @ms = map { substr($starts[$id-1],$codons->{$_},1) } _unambiquous_codons($value);
+       my @ms = map { substr($STARTS[$id-1],$CODONS->{$_},1) } _unambiquous_codons($value);
        foreach my $c (@ms) {
 	   $result = 0 if $c ne 'M';
        }
@@ -603,9 +586,9 @@ sub is_ter_codon{
    }
    else {
        my $result = 1;
-       my @ms = map { substr($tables[$id-1],$codons->{$_},1) } _unambiquous_codons($value);
+       my @ms = map { substr($TABLES[$id-1],$CODONS->{$_},1) } _unambiquous_codons($value);
        foreach my $c (@ms) {
-	   $result = 0 if $c ne '*';
+	   $result = 0 if $c ne $TERMINATOR;
        }
        return $result;
    }
@@ -636,7 +619,7 @@ sub is_unknown_codon{
    }
    else {
        my $result = 0;
-       my @cs = map { substr($tables[$id-1],$codons->{$_},1) } _unambiquous_codons($value);
+       my @cs = map { substr($TABLES[$id-1],$CODONS->{$_},1) } _unambiquous_codons($value);
        $result = 1 if scalar @cs == 0;
        return $result;
    }
@@ -658,19 +641,15 @@ sub _unambiquous_codons{
     my @nts = ();
     my @codons = ();
     my ($i, $j, $k);
-    @nts = map { $iupac_dna{$_} }  split(//, $value) ;
-    for $i (0..$#{$nts[0]}) {
-	for $j (0..$#{$nts[1]}) {
-	    for $k (0..$#{$nts[2]}) {
-		#print join ('', $nts[0][$i], $nts[1][$j], $nts[2][$k]), "\n"; ###
-		push @codons, join ('', $nts[0][$i], $nts[1][$j], $nts[2][$k]);
+    @nts = map { $IUPAC_DNA{uc $_} }  split(//, $value);
+    for my $i (@{$nts[0]}) {
+	for my $j (@{$nts[1]}) {
+	    for my $k (@{$nts[2]}) {
+		push @codons, lc "$i$j$k";
 	    }
 	}
     }
     return @codons;
 }
 
-
-}
-
 1;
