@@ -1,4 +1,4 @@
-# $Id: IUPAC.pm,v 1.10.2.1 2001/03/03 08:28:58 heikki Exp $
+# $Id: IUPAC.pm,v 1.15 2001/12/11 21:30:27 jason Exp $
 #
 # BioPerl module for IUPAC
 #
@@ -98,10 +98,9 @@ the meaning shown below)
 
 =head2 Mailing Lists
 
-User feedback is an integral part of the evolution of this
-and other Bioperl modules. Send your comments and suggestions preferably
- to one of the Bioperl mailing lists.
-Your participation is much appreciated.
+User feedback is an integral part of the evolution of this and other
+Bioperl modules. Send your comments and suggestions preferably to one
+of the Bioperl mailing lists.  Your participation is much appreciated.
 
   bioperl-l@bioperl.org             - General discussion
   http://www.bioperl.org/MailList.html - About the mailing lists
@@ -109,8 +108,8 @@ Your participation is much appreciated.
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via email
+or the web:
 
   bioperl-bugs@bioperl.org
   http://www.bioperl.org/bioperl-bugs/
@@ -121,7 +120,8 @@ Email amackey@virginia.edu
 
 =head1 APPENDIX
 
-The rest of the documentation details each of the object methods. Internal methods are usually preceded with a _
+The rest of the documentation details each of the object
+methods. Internal methods are usually preceded with a _
 
 =cut
 
@@ -131,10 +131,58 @@ The rest of the documentation details each of the object methods. Internal metho
 package Bio::Tools::IUPAC;
 
 use strict;
-use vars qw(@ISA $AUTOLOAD);
+use vars qw(@ISA %IUP %IUB $AUTOLOAD);
 
-use Bio::Root::RootI;
-@ISA = qw(Bio::Root::RootI);
+BEGIN {
+    %IUB = ( A => [qw(A)],
+	     C => [qw(C)],
+	     G => [qw(G)],
+	     T => [qw(T)],
+	     U => [qw(U)],
+	     M => [qw(A C)],
+	     R => [qw(A G)],
+	     W => [qw(A T)],
+	     S => [qw(C G)],
+	     Y => [qw(C T)],
+	     K => [qw(G T)],
+	     V => [qw(A C G)],
+	     H => [qw(A C T)],
+	     D => [qw(A G T)],
+	     B => [qw(C G T)],
+	     X => [qw(G A T C)],
+	     N => [qw(G A T C)]
+	     );
+
+    %IUP = (A => [qw(A)],
+	    B => [qw(D N)],
+	    C => [qw(C)],
+	    D => [qw(D)],
+	    E => [qw(E)],
+	    F => [qw(F)],
+	    G => [qw(G)],
+	    H => [qw(H)],
+	    I => [qw(I)],
+	    K => [qw(K)],
+	    L => [qw(L)],
+	    M => [qw(M)],
+	    N => [qw(N)],
+	    P => [qw(P)],
+	    Q => [qw(Q)],
+	    R => [qw(R)],
+	    S => [qw(S)],
+	    T => [qw(T)],
+	    U => [qw(U)],
+	    V => [qw(V)],
+	    W => [qw(W)],
+	    X => [qw(X)],
+	    Y => [qw(Y)],
+	    Z => [qw(E Q)],
+	    '*' => ['*']
+	    );
+    
+}
+use Bio::Root::Root;
+@ISA = qw(Bio::Root::Root);
 
 =head2 new
 
@@ -160,54 +208,10 @@ sub new {
     }
     $seq->isa('Bio::Seq') or $self->throw("Must supply a Seq.pm object to IUPAC!");
     $self->{'_SeqObj'} = $seq;
-    if ($self->{'_SeqObj'}->moltype() =~ m/^[dr]na$/i ) { # nucleotide seq object
-	$self->{'_iupac_iub'} = { A => [qw(A)],
-				  C => [qw(C)],
-				  G => [qw(G)],
-				  T => [qw(T)],
-				  U => [qw(U)],
-				  M => [qw(A C)],
-				  R => [qw(A G)],
-				  W => [qw(A T)],
-				  S => [qw(C G)],
-				  Y => [qw(C T)],
-				  K => [qw(G T)],
-				  V => [qw(A C G)],
-				  H => [qw(A C T)],
-				  D => [qw(A G T)],
-				  B => [qw(C G T)],
-				  X => [qw(G A T C)],
-				  N => [qw(G A T C)]
-				};
-	$self->{'_alpha'} = [ map { $self->{'_iupac_iub'}{uc($_)} } split('', $self->{'_SeqObj'}->seq()) ];
-    } elsif ($self->{'_SeqObj'}->moltype() =~ m/^protein$/i ) { # amino acid seq object
-	$self->{'_iupac_iup'} = { A => [qw(A)],
-				  B => [qw(D N)],
-				  C => [qw(C)],
-				  D => [qw(D)],
-				  E => [qw(E)],
-				  F => [qw(F)],
-				  G => [qw(G)],
-				  H => [qw(H)],
-				  I => [qw(I)],
-				  K => [qw(K)],
-				  L => [qw(L)],
-				  M => [qw(M)],
-				  N => [qw(N)],
-				  P => [qw(P)],
-				  Q => [qw(Q)],
-				  R => [qw(R)],
-				  S => [qw(S)],
-				  T => [qw(T)],
-				  U => [qw(U)],
-				  V => [qw(V)],
-				  W => [qw(W)],
-				  X => [qw(X)],
-				  Y => [qw(Y)],
-				  Z => [qw(E Q)],
-				  '*' => ['*']
-				};
-	$self->{'_alpha'} = [ map { $self->{'_iupac_iup'}{uc($_)} } split('', $self->{'_SeqObj'}->seq()) ];
+    if ($self->{'_SeqObj'}->alphabet() =~ m/^[dr]na$/i ) { # nucleotide seq object
+	$self->{'_alpha'} = [ map { $IUB{uc($_)} } split('', $self->{'_SeqObj'}->seq()) ];
+    } elsif ($self->{'_SeqObj'}->alphabet() =~ m/^protein$/i ) { # amino acid seq object
+	$self->{'_alpha'} = [ map { $IUP{uc($_)} } split('', $self->{'_SeqObj'}->seq()) ];
     } else { # unknown type: we could make a guess, but let's not.
 	$self->throw("You must specify the 'type' of sequence provided to IUPAC");
     }
@@ -257,6 +261,35 @@ sub next_seq{
     }
 }
 
+=head2 iupac_iup
+
+ Title   : iupac_iup
+ Usage   : my %aasymbols = $iupac->iupac_iup
+ Function: Returns a hash of PROTEIN symbols -> symbol components
+ Returns : Hash
+ Args    : none
+
+=cut
+
+sub iupac_iup{
+   return %IUP;
+
+}
+
+=head2 iupac_iub
+
+ Title   : iupac_iub
+ Usage   : my %dnasymbols = $iupac->iupac_iub
+ Function: Returns a hash of DNA symbols -> symbol components
+ Returns : Hash
+ Args    : none
+
+=cut
+
+sub iupac_iub{
+   return %IUB;
+}
+
 sub AUTOLOAD {
 
     my $self = shift @_;
