@@ -1,37 +1,14 @@
-#-----------------------------------------------------------------------------
-# PACKAGE : Bio::Tools::SeqPattern.pm
-# AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
-# CREATED : 28 Aug 1997
-# REVISION: $Id: SeqPattern.pm,v 1.1.1.1 1998/12/11 15:24:23 birney Exp $
-#            
-# Copyright (c) 1997-8 Steve A. Chervitz. All Rights Reserved.
-#           This module is free software; you can redistribute it and/or 
-#           modify it under the same terms as Perl itself.
-#-----------------------------------------------------------------------------
+# $Id: SeqPattern.pm,v 1.11 2002/02/25 15:30:56 heikki Exp $
+#
+# bioperl module for Bio::Tools::SeqPattern
+#
+# Cared for by  Steve Chervitz  (sac@bioperl.org)
+#
+# Copyright  Steve Chervitz 
+#
+# You may distribute this module under the same terms as perl itself
 
-package Bio::Tools::SeqPattern;
-
-use Bio::Root::Global qw(:devel);
-use Bio::Seq ();
-
-@ISA = qw(Bio::Seq);
-use strict;
-use vars qw ($ID $VERSION);
-$ID  = 'Bio::Tools::SeqPattern';
-$VERSION = 0.011;
-
-## These constants may be more appropriate in a Bio::Dictionary.pm 
-## type of class.
-my $PURINES      = 'AG';
-my $PYRIMIDINES  = 'CT';
-my $PHILICS      = 'TSHEDQNKR';
-my $PHOBICS      = 'IFVLWMAGCY';
-my $Regexp_chars = '\w,.\*()\[\]<>\{\}^\$';  # quoted for use in regexps
-
-## Package variables used in reverse complementing.
-my (%Processed_braces, %Processed_asterics);
-
-## POD Documentation:
+# POD documentation - main docs before the code
 
 =head1 NAME
 
@@ -49,21 +26,14 @@ Bio::Tools::SeqPattern.pm - Bioperl object for a sequence pattern or motif
     $pat2     = '[VILM]R(GXX){3,2}...[^PG]';
     $pattern2 = new Bio::Tools::SeqPattern(-SEQ =>$pattern, -TYPE =>'Amino'); 
 
-=head1 INSTALLATION
-
-This module is included with the central Bioperl distribution:
-
-   http://bio.perl.org/Core/Latest
-   ftp://bio.perl.org/pub/DIST
-
-Follow the installation instructions included in the README file.
-
 =head1 DESCRIPTION
 
-The Bio::Tools::SeqPattern.pm module encapsulates generic data and methods for manipulating 
-regular expressions describing nucleic or amino acid sequence patterns (a.k.a, "motifs").
+The Bio::Tools::SeqPattern.pm module encapsulates generic data and
+methods for manipulating regular expressions describing nucleic or
+amino acid sequence patterns (a.k.a, "motifs").
 
-Bio::Tools::SeqPattern.pm is a concrete class that inherits from B<Bio::Seq.pm>.
+Bio::Tools::SeqPattern.pm is a concrete class that inherits from
+B<Bio::Seq.pm>.
 
 This class grew out of a need to have a standard module for doing routine
 tasks with sequence patterns such as:
@@ -74,7 +44,7 @@ tasks with sequence patterns such as:
   -- Untainting yet preserving special characters in the pattern
 
 Other features to look for in the future:
- 
+
   -- Full pattern syntax checking
   -- Conversion between expanded and ondensed forms of the pattern
 
@@ -84,13 +54,13 @@ A key motivation for Bio::Tools::SeqPattern.pm is to have a way to
 generate a reverse complement of a nucleotide sequence pattern.
 This makes possible simultaneous pattern matching on both sense and 
 anti-sense strands of a query sequence. 
- 
+
 In principle, one could do such a search more inefficiently by testing 
-ainst both sense and anti-sense versions of a sequence. 
+against both sense and anti-sense versions of a sequence. 
 It is entirely equivalent to test a regexp containing both sense and 
 anti-sense versions of the *pattern* against one copy of the sequence.
 The latter approach is much more efficient since:
- 
+
    1) You need only one copy of the sequence.
    2) Only one regexp is executed.
    3) Regexp patterns are typically much smaller than sequences.
@@ -102,7 +72,7 @@ for working with biological sequence regular expressions.
 
 Not all patterns have been tested. If you discover a pattern that
 is not handled properly by Bio::Tools::SeqPattern.pm, please
-send me some email (sac@genome.stanford.edu). Thanks.
+send me some email (sac@bioperl.org). Thanks.
 
 =head1 OTHER FEATURES
 
@@ -111,7 +81,6 @@ send me some email (sac@genome.stanford.edu). Thanks.
 This module supports the same set of ambiguity codes for nucleotide 
 sequences as supported by B<Bio::Seq.pm>. These ambiguity codes
 define the behavior or the expand() method.
-Amino acid alphabet support is different from that of Seq.pm (see below).
 
  ------------------------------------------
  Symbol       Meaning      Nucleic Acid
@@ -161,58 +130,56 @@ Amino acid alphabet support is different from that of Seq.pm (see below).
  W        Tryptophan
  Y        Tyrosine
 
- B        Any hydrophobic: IFVLWMAGCY
- Z        Any hydrophilic: TSHEDQNKR
+ B        Aspartic Acid, Asparagine
+ Z        Glutamic Acid, Glutamine
  X        Any amino acid
  .        Any amino acid
 
 
 =head2   Multiple Format Support
 
-Ultimately, this module should be able to build SeqPattern.pm objects objects 
+Ultimately, this module should be able to build SeqPattern.pm objects
 using a variety of pattern formats such as ProSite, Blocks, Prints, GCG, etc.
-Currently, this module only supports patterns using a grep-like syntax. 
+Currently, this module only supports patterns using a grep-like syntax.
 
 =head1 USAGE
 
-A simple demo script is included with the central Bioperl distribution (L<INSTALLATION>)
-and is also available from:
+A simple demo script is included in the examples/ directory of the central
+Bioperl distribution and is also available from:
 
     http://bio.perl.org/Core/Examples/seq_pattern.pl
 
 =head1 SEE ALSO
 
-  Bio::Root::Object.pm    - Base class.
-  Bio::Seq.pm             - Lightweight sequence object.
+L<Bio::Root::Object>   - Base class.
+L<Bio::Seq>            - Lightweight sequence object.
 
-  http://bio.perl.org/Projects/modules.html  - Online module documentation
-  http://bio.perl.org/                       - Bioperl Project Homepage 
+http://bio.perl.org/Projects/modules.html  - Online module documentation
+http://bio.perl.org/                       - Bioperl Project Homepage 
 
 =head1 FEEDBACK
 
 =head2 Mailing Lists 
 
-User feedback is an integral part of the evolution of this and other Bioperl modules.
-Send your comments and suggestions preferably to one of the Bioperl mailing lists.
-Your participation is much appreciated.
+User feedback is an integral part of the evolution of this and other
+Bioperl modules.  Send your comments and suggestions preferably to one
+of the Bioperl mailing lists.  Your participation is much appreciated.
 
-    vsns-bcd-perl@lists.uni-bielefeld.de          - General discussion
-    vsns-bcd-perl-guts@lists.uni-bielefeld.de     - Technically-oriented discussion
-    http://bio.perl.org/MailList.html             - About the mailing lists
+    bioperl-l@bioperl.org              - General discussion
+    http://bio.perl.org/MailList.html  - About the mailing lists
 
 =head2 Reporting Bugs
 
-Report bugs to the Bioperl bug tracking system to help us keep track the bugs and 
-their resolution. Bug reports can be submitted via email or the web:
+Report bugs to the Bioperl bug tracking system to help us keep track
+the bugs and their resolution. Bug reports can be submitted via email
+or the web:
 
-    bioperl-bugs@bio.perl.org                   
-    http://bio.perl.org/bioperl-bugs/           
+    bioperl-bugs@bio.perl.org
+    http://bio.perl.org/bioperl-bugs/
 
 =head1 AUTHOR
 
-Steve A. Chervitz, sac@genome.stanford.edu
-
-See the L<FEEDBACK> section for where to send bug reports and comments.
+Steve Chervitz, sac@bioperl.org
 
 =head1 VERSION
 
@@ -220,7 +187,7 @@ Bio::Tools::SeqPattern.pm, 0.011
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-8 Steve A. Chervitz. All Rights Reserved.
+Copyright (c) 1997-8 Steve Chervitz. All Rights Reserved.
 This module is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
 
@@ -233,18 +200,38 @@ modify it under the same terms as Perl itself.
 ###
 ##
 #'
+# CREATED : 28 Aug 1997
 
 
+package Bio::Tools::SeqPattern;
+
+use Bio::Root::Root;
+@ISA = qw(Bio::Root::Root);
+use strict;
+use vars qw ($ID $VERSION);
+$ID  = 'Bio::Tools::SeqPattern';
+$VERSION = 0.011;
+
+## These constants may be more appropriate in a Bio::Dictionary.pm 
+## type of class.
+my $PURINES      = 'AG';
+my $PYRIMIDINES  = 'CT';
+my $BEE      = 'DN';
+my $ZED      = 'EQ';
+my $Regexp_chars = '\w,.\*()\[\]<>\{\}^\$';  # quoted for use in regexps
+
+## Package variables used in reverse complementing.
+my (%Processed_braces, %Processed_asterics);
 
 #####################################################################################
 ##                                 CONSTRUCTOR                                     ##
 #####################################################################################
 
 
-=head1 _initialize
+=head1 new
 
- Title     : _initialize
- Usage     : n/a; automatically called by Bio::Root::Object::new()
+ Title     : new
+ Usage     : my $seqpat = new Bio::Tools::SeqPattern();
  Purpose   : Verifies that the type is correct for superclass (Bio::Seq.pm)
            : and calls superclass constructor last.
  Returns   : n/a
@@ -253,34 +240,32 @@ modify it under the same terms as Perl itself.
  Comments  : The process of creating a new SeqPattern.pm object
            : ensures that the pattern string is untained.
 
-See Also   : L<_untaint_pat>(), B<Bio::Root::Object::new()>, B<Bio::Seq::_initialize()>
+See Also   : B<Bio::Root::Root::new()>, 
+             B<Bio::Seq::_initialize()>
 
 =cut
 
 #----------------
-sub _initialize {
+sub new {
 #----------------
-    my($self, %param) = @_;
+    my($class, %param) = @_;
     
-    my($seq, $type) = $self->_rearrange([qw(SEQ TYPE)], %param);
+    my $self = $class->SUPER::new(%param);
+    my ($seq,$type) = $self->_rearrange([qw(SEQ TYPE)], %param);
 
     $seq || $self->throw("Empty pattern.");
-
+    my $t;
     # Get the type ready for Bio::Seq.pm
     if ($type =~ /nuc|[dr]na/i) {
-	$param{-TYPE} = 'Dna';
+	$t = 'Dna';
     } elsif ($type =~ /amino|pep|prot/i) {
-	$param{-TYPE} = 'Amino';
+	$t = 'Amino';
     }
+    $seq =~ tr/a-z/A-Z/;  #ps 8/8/00 Canonicalize to upper case
+    $self->str($seq);
+    $self->type($t);
 
-    my $make = $self->SUPER::_initialize(%param);
-#	 if($self->make() =~ /^nuc/i) {
-#	     $param{-SEQ} = $self->_expand_nuc($param{-SEQ}); 
-#	 } else {
-##	    $param{-SEQ} = $self->_expand_pep($param{-SEQ});  #unimplemented here.
-#	 }
-
-    $make;
+    return $self;
 }
 
 
@@ -298,11 +283,9 @@ sub _initialize {
  Argument  : n/a
  Throws    : Exception if the pattern contains invalid characters.
  Comments  : Does not call the superclass method.
-           : Actaully permits any alphanumeric, not just the
+           : Actually permits any alphanumeric, not just the
            : standard genetic alphabet.
 
-See Also   : B<Bio::Seq::alphabet_ok()>, L<_initialize>()
-
 =cut
 
 #----------------'
@@ -328,8 +311,6 @@ sub alphabet_ok {
     1;
 }
 
-
-
 =head1 expand
 
  Title     : expand
@@ -341,7 +322,7 @@ sub alphabet_ok {
  Throws    : Exception if sequence type is not recognized 
            : (i.e., is not one of [DR]NA, Amino)
 
-See Also   : B<Extended Alphabet Support>, L<_expand_pep>(), L<_exapand_nuc>()
+See Also   : B<Extended Alphabet Support>, L<_expand_pep>(), L<_expand_nuc>()
 
 =cut
 
@@ -380,16 +361,16 @@ sub _expand_pep {
     $pat =~ s/^</\^/;
     $pat =~ s/>$/\$/;
 
-    ## Avoid nested situations: [bmnq] --/--> [[$PHOBICS]mnq]
-    ## Yet correctly deal with: fze[bmnq] ---> f[$PHILICS]e[$PHOBICSmnq]
+    ## Avoid nested situations: [bmnq] --/--> [[$ZED]mnq]
+    ## Yet correctly deal with: fze[bmnq] ---> f[$BEE]e[$ZEDmnq]
     if($pat =~ /\[\w*[BZ]\w*\]/) {
-	$pat =~ s/\[(\w*)B(\w*)\]/\[$1$PHOBICS$2\]/g;
-	$pat =~ s/\[(\w*)Z(\w*)\]/\[$1$PHILICS$2\]/g;
-	$pat =~ s/B/\[$PHOBICS\]/g;
-	$pat =~ s/Z/\[$PHILICS\]/g;
+	$pat =~ s/\[(\w*)B(\w*)\]/\[$1$ZED$2\]/g;
+	$pat =~ s/\[(\w*)Z(\w*)\]/\[$1$BEE$2\]/g;
+	$pat =~ s/B/\[$ZED\]/g;
+	$pat =~ s/Z/\[$BEE\]/g;
     } else {
-	$pat =~ s/B/\[$PHOBICS\]/g;
-	$pat =~ s/Z/\[$PHILICS\]/g;
+	$pat =~ s/B/\[$ZED\]/g;
+	$pat =~ s/Z/\[$BEE\]/g;
     }
     $pat =~ s/\((.)\)/$1/g;  ## Doing these last since:
     $pat =~ s/\[(.)\]/$1/g;  ## Pattern could contain [B] (for example)
@@ -493,7 +474,7 @@ See Also   : B<Bio::Seq::revcom()>, L<_fixpat_1>(), L<_fixpat_2>(), L<_fixpat_3>
 
 =cut
 
-#-----------
+#-----------'
 sub revcom {
 #-----------
     my($self,$expand) = @_;
@@ -504,7 +485,9 @@ sub revcom {
 #    return $self->{'_rev'} if defined $self->{'_rev'};
 
     $expand ||= 0;
-    my $rev = $self->SUPER::revcom->str;  ## Invoke Bio::Seq::revcom()
+    my $str = $self->str;
+    $str =~ tr/acgtrymkswhbvdnxACGTRYMKSWHBVDNX/tgcayrkmswdvbhnxTGCAYRKMSWDVBHNX/;
+    my $rev = CORE::reverse $str;
     $rev    =~ tr/[](){}<>/][)(}{></;
 
     if($expand) {
@@ -529,7 +512,11 @@ sub revcom {
     
      $fixrev = _fixpat_5($fixrev);
 #    print "FIX 5: $fixrev";<STDIN>;
-    
+
+##### Added by ps 8/7/00 to allow non-greedy matching
+     $fixrev = _fixpat_6($fixrev);
+#    print "FIX 6: $fixrev";<STDIN>;
+
 #    $self->{'_rev'} = $fixrev;
 
      return new Bio::Tools::SeqPattern(-seq =>$fixrev, -type =>$self->type);
@@ -670,17 +657,17 @@ sub _fixpat_3 {
 #	$pat =~ s/(.+)(\{\S+\})(\(\w+\))(.*)/$1#$3$2$4/ or do{ push @done, $pat; last; };
 	if( $pat =~ /(.*)(.)(\{\S+\})(\(\w+\))(.*)/) {
 	    $newpat = "$1#$2$4$3$5";
-	    $oldpat = "$1#$2$3$4$5";
+##ps	    $oldpat = "$1#$2$3$4$5";
 #	    print "1: $1\n2: $2\n3: $3\n4: $4\n5: $5\n";
-	    $braces = $3;
-	    $braces =~ s/[{}]//g;
-	    if( exists $Processed_braces{"$2$braces"} || exists $Processed_asterics{$2}) {
-		$pat = $oldpat;  # Don't change it. Already processed.
+##ps	    $braces = $3;
+##ps	    $braces =~ s/[{}]//g;
+##ps	    if( exists $Processed_braces{"$2$braces"} || exists $Processed_asterics{$2}) {
+##ps		$pat = $oldpat;  # Don't change it. Already processed.
 #		print "saved pat: $pat";<STDIN>;
-	    } else {
+##ps	    } else {
 #		print "new pat: $newpat";<STDIN>;
 		$pat = $newpat;  # Change it.
-	    }
+##ps	    }
 	} elsif( $pat =~ /^(\{\S+\})(\(\w+\))(.*)/) {
 	    $pat = "#$2$1$3";
 	} else { 
@@ -725,7 +712,8 @@ sub _fixpat_4 {
 #	    print "1: $1\n2: $2\n3: $3\n4: $4\n5: $5\n";
 	    $braces = $3;
 	    $braces =~ s/[{}]//g;
-	    if( exists $Processed_braces{"$2$braces"} || exists $Processed_asterics{$2}) {
+	    if( (defined $braces and defined $2) and
+		exists $Processed_braces{"$2$braces"} || exists $Processed_asterics{$2}) {
 		$pat = $oldpat;  # Don't change it. Already processed.
 #		print "saved pat: $pat";<STDIN>;
 	    } else {
@@ -798,7 +786,101 @@ sub _fixpat_5 {
     return join('', reverse @done);
 }
 
+
+
+
+
+############################
+#
+#  PS: Added 8/7/00 to allow non-greedy matching patterns
+#
+######################################
+
+=head1 _fixpat_6
+
+ Title     : _fixpat_6
+ Usage     : n/a; called automatically by revcom()
+ Purpose   : Utility method for revcom()
+           : Converts all ?Y{5,7}  ---> Y{5,7}?
+           :          and ?(XXX){5,7}  ---> (XXX){5,7}?
+           :          and ?[XYZ]{5,7}  ---> [XYZ]{5,7}?
+ Returns   : String (the new, partially reversed pattern)
+ Argument  : String (the expanded, partially reversed pattern)
+ Throws    : n/a
+
+See Also   : L<revcom>()
+
+=cut
+
+#--------------
+sub _fixpat_6 {
+#--------------
+    my $pat = shift;
+    my (@done,@parts);
+
+   @done = ();
+    while(1) {
+	$pat =~   /(.*)\?(\[\w+\]|\(\w+\)|\w)(\{\S+?\})?(.*)/ or do{ push @done, $pat; last; };
+     my $quantifier = $3 ? $3 : ""; # Shut up warning if no explicit quantifier
+ 	$pat = $1.'#'.$2.$quantifier.'?'.$4;
+#	$pat = $1.'#'.$2.$3.'?'.$4;
+
+#	print "1: $1\n2: $2\n3: $3\n";
+#	print "modified pat: $pat";<STDIN>;
+	@parts = split '#', $pat;
+	push @done, $parts[1];
+	$pat = $parts[0];
+#	print "done: $parts[1]<---\nnew pat: $pat<---";<STDIN>;
+	last if not $pat;
+    }
+    return join('', reverse @done);
+
+ }
+
+=head2 str
+
+ Title   : str
+ Usage   : $obj->str($newval)
+ Function: 
+ Returns : value of str
+ Args    : newvalue (optional)
+
+
+=cut
+
+sub str{
+   my $obj = shift;
+   if( @_ ) {
+      my $value = shift;
+      $obj->{'str'} = $value;
+    }
+    return $obj->{'str'};
+
+}
+
+=head2 type
+
+ Title   : type
+ Usage   : $obj->type($newval)
+ Function: 
+ Returns : value of type
+ Args    : newvalue (optional)
+
+
+=cut
+
+sub type{
+   my $obj = shift;
+   if( @_ ) {
+      my $value = shift;
+      $obj->{'type'} = $value;
+    }
+    return $obj->{'type'};
+
+}
+
 1;
+
 __END__
 
 #########################################################################
@@ -809,26 +891,29 @@ __END__
 
 =head2 Data Members
 
-Information about the various data members of this module is provided for those 
-wishing to modify or understand the code. Two things to bear in mind: 
+Information about the various data members of this module is provided
+for those wishing to modify or understand the code. Two things to bear
+in mind:
 
-=over 4
+=over 2
 
 =item 1 Do NOT rely on these in any code outside of this module. 
 
-All data members are prefixed with an underscore to signify that they are private.
-Always use accessor methods. If the accessor doesn't exist or is inadequate, 
-create or modify an accessor (and let me know, too!). 
+All data members are prefixed with an underscore to signify that they
+are private.  Always use accessor methods. If the accessor doesn't
+exist or is inadequate, create or modify an accessor (and let me know,
+too!).
 
 =item 2 This documentation may be incomplete and out of date.
 
-It is easy for this documentation to become obsolete as this module is still evolving. 
-Always double check this info and search for members not described here.
+It is easy for this documentation to become obsolete as this module is
+still evolving.  Always double check this info and search for members
+not described here.
 
 =back
 
-An instance of Bio::Tools::RestrictionEnzyme.pm is a blessed reference to a hash
-containing all or some of the following fields:
+An instance of Bio::Tools::RestrictionEnzyme.pm is a blessed reference
+to a hash containing all or some of the following fields:
 
  FIELD          VALUE
  ------------------------------------------------------------------------
@@ -841,6 +926,3 @@ containing all or some of the following fields:
 
 
 =cut
-
-
-
