@@ -1,4 +1,4 @@
-# $Id: Allele.pm,v 1.3.2.2 2001/06/21 15:36:05 heikki Exp $
+# $Id: Allele.pm,v 1.6 2002/02/18 17:17:25 bosborne Exp $
 #
 # BioPerl module for Bio::Variation::Allele
 #
@@ -18,14 +18,15 @@ Bio::Variation::Allele - Sequence object with allele-specific attributes
 
   $allele1 = Bio::Variation::Allele->new ( -seq => 'A',
                                            -id  => 'AC00001.1',
-                                           -moltype => 'dna',
+                                           -alphabet => 'dna',
                                            -is_reference => 1
                                          );
 
 =head1 DESCRIPTION
 
 List of alleles describe known sequence alternatives in a variable region.
-Alleles are contained in L<Bio::Variation::VariantI> complying objects.
+Alleles are contained in Bio::Variation::VariantI complying objects.
+See L<Bio::Variation::VariantI> for details.
 
 Bio::Varation::Alleles are PrimarySeqI complying objects which can
 contain database cross references as specified in
@@ -79,7 +80,7 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Variation::Allele;
-my $version=1.0;
+my $VERSION=1.0;
 use vars qw(@ISA);
 use strict;
 
@@ -93,14 +94,14 @@ use Bio::DBLinkContainerI;
 sub _initialize {
     my($self, @args) = @_;
 
-    my($seq,$id,$acc,$pid,$desc,$moltype,$given_id, 
+    my($seq,$id,$acc,$pid,$desc,$alphabet,$given_id, 
        $is_reference, $repeat_unit, $repeat_count) =
 	   $self->_rearrange([qw(SEQ
 				 DISPLAY_ID
 				 ACCESSION_NUMBER
 				 PRIMARY_ID
 				 DESC
-				 MOLTYPE
+				 ALPHABET
 				 ID
 				 IS_REFERENCE
 				 REPEAT_UNIT
@@ -117,7 +118,7 @@ sub _initialize {
     $acc     && $self->SUPER::accession_number($acc);
     $pid     && $self->SUPER::primary_id($pid);
     $desc    && $self->SUPER::desc($desc);
-    $moltype && $self->SUPER::moltype($moltype);
+    $alphabet && $self->SUPER::alphabet($alphabet);
 
     $is_reference && $self->is_reference($is_reference);
     $repeat_unit && $self->repeat_unit($repeat_unit);
