@@ -1,4 +1,4 @@
-# $Id: VariantI.pm,v 1.5.2.4 2001/06/21 15:36:05 heikki Exp $
+# $Id: VariantI.pm,v 1.10 2002/02/18 17:17:25 bosborne Exp $
 #
 # BioPerl module for Bio::Variation::VariantI
 #
@@ -25,20 +25,24 @@ Bio::Variation::VariantI - Sequence Change SeqFeature abstract class
 =head1 DESCRIPTION
 
 This superclass defines common methods to basic sequence changes.  The
-instantiable classes L<Bio::Variation::DNAMutation>,
-L<Bio::Variation::RNAChange> and L<Bio::Variation::AAChange> use them.
+instantiable classes Bio::Variation::DNAMutation,
+Bio::Variation::RNAChange and Bio::Variation::AAChange use them.
+See L<Bio::Variation::DNAMutation>, L<Bio::Variation::RNAChange>,
+and L<Bio::Variation::AAChange> for more information.
 
 These classes store information, heavy computation to detemine allele
 sequences is done elsewhere.
 
 The database cross-references are implemented as
-L<Bio::Annotation::DBLink> objects. The methods to access them are
-defined in L<Bio::DBLinkContainerI>.
+Bio::Annotation::DBLink objects. The methods to access them are
+defined in Bio::DBLinkContainerI. See L<Bio::Annotation::DBLink>
+and L<Bio::DBLinkContainerI> for details.
 
 Bio::Variation::VariantI redifines and extends
-L<Bio::SeqFeature::Generic> for sequence variations. This class
+Bio::SeqFeature::Generic for sequence variations. This class
 describes specific sequence change events. These events are always
-from a specific reference sequence to something different.
+from a specific reference sequence to something different. See
+L<Bio::SeqFeature::Generic> for more information.
 
 IMPORTANT: The notion of reference sequence permeates all
 Bio::Variation classes. This is especially important to remember when
@@ -94,15 +98,15 @@ methods. Internal methods are usually preceded with a _
 
 
 package Bio::Variation::VariantI;
-$version=1.0;
+$VERSION=1.0;
 use vars qw(@ISA);
 use strict;
-use  Bio::Root::RootI;
+use  Bio::Root::Root;
 use  Bio::DBLinkContainerI;
 # Object preamble - inheritance
 
 use Bio::SeqFeature::Generic;
-@ISA = qw(Bio::Root::RootI Bio::SeqFeature::Generic Bio::DBLinkContainerI );
+@ISA = qw(Bio::Root::Root Bio::SeqFeature::Generic Bio::DBLinkContainerI );
 
 =head2 id
 
@@ -224,7 +228,7 @@ sub isMutation {
  Usage   : $obj->allele_ori();
  Function: 
 
-            Links to and returns the L<Bio::Variation::Allele> object.
+            Links to and returns the Bio::Variation::Allele object.
             If value is not set, returns false. All other Alleles are
             compared to this.
 
@@ -235,6 +239,8 @@ sub isMutation {
  Returns : string
  Args    : string
 
+See L<Bio::Variation::Allele> for more.
+
 =cut
 
 sub allele_ori {
@@ -261,7 +267,7 @@ sub allele_ori {
  Usage   : $obj->allele_mut();
  Function: 
 
-             Links to and returns the L<Bio::Variation::Allele>
+             Links to and returns the Bio::Variation::Allele
              object.  Sets and returns the mutated allele sequence.
              If value is not set, returns false.
 
@@ -272,6 +278,8 @@ sub allele_ori {
  Returns : string
  Args    : string
 
+See L<Bio::Variation::Allele> for more.
+
 =cut
 
 
@@ -639,7 +647,7 @@ sub mut_number {
  Function: 
 
            Returns or sets the link-reference to the umbrella
-           L<Bio::Variation::SeqDiff> object.  If there is no link,
+           Bio::Variation::SeqDiff object.  If there is no link,
            it will return undef
 
            Note: Adding a variant into a SeqDiff object will
@@ -647,6 +655,8 @@ sub mut_number {
 
  Returns : an obj_ref or undef
 
+See L<Bio::Variation::SeqDiff> for more information.
+
 =cut
 
 sub SeqDiff {
